@@ -11,15 +11,14 @@ import (
 	"github.com/hetznercloud/hcloud-go/v2/hcloud"
 )
 
-var SetRDNSCmd = base.SetRdnsCmd{
+var SetRDNSCmd = base.SetRdnsCmd[*hcloud.FloatingIP]{
 	ResourceNameSingular: "Floating IP",
 	ShortDescription:     "Change reverse DNS of a Floating IP",
 	NameSuggestions:      func(c hcapi2.Client) func() []string { return c.FloatingIP().Names },
-	Fetch: func(s state.State, _ *cobra.Command, idOrName string) (interface{}, *hcloud.Response, error) {
+	Fetch: func(s state.State, _ *cobra.Command, idOrName string) (*hcloud.FloatingIP, *hcloud.Response, error) {
 		return s.Client().FloatingIP().Get(s, idOrName)
 	},
-	GetDefaultIP: func(resource interface{}) net.IP {
-		floatingIP := resource.(*hcloud.FloatingIP)
+	GetDefaultIP: func(floatingIP *hcloud.FloatingIP) net.IP {
 		return floatingIP.IP
 	},
 }
