@@ -35,7 +35,16 @@ func TestDescribe(t *testing.T) {
 		Blocked:      true,
 		AutoDelete:   false,
 		AssigneeType: "server",
-		Datacenter:   &hcloud.Datacenter{ID: 0, Location: &hcloud.Location{ID: 0}},
+		Location: &hcloud.Location{
+			ID:          3,
+			Name:        "hel1",
+			Description: "Helsinki DC Park 1",
+			NetworkZone: "eu-central",
+			Country:     "FI",
+			City:        "Helsinki",
+			Latitude:    60.169855,
+			Longitude:   24.938379,
+		},
 	}
 
 	fx.Client.PrimaryIPClient.EXPECT().
@@ -64,20 +73,15 @@ Protection:
 Labels:
   No labels
 
-Datacenter:
-  ID:           0
-  Name:         
-  Description:  
-  
-  Location:
-    ID:            0
-    Name:          
-    Description:   
-    Network Zone:  
-    Country:       
-    City:          
-    Latitude:      0.000000
-    Longitude:     0.000000
+Location:
+  ID:            3
+  Name:          hel1
+  Description:   Helsinki DC Park 1
+  Network Zone:  eu-central
+  Country:       FI
+  City:          Helsinki
+  Latitude:      60.169855
+  Longitude:     24.938379
 `, util.Datetime(primaryIP.Created), humanize.Time(primaryIP.Created))
 
 	require.NoError(t, err)
