@@ -9,6 +9,7 @@ import (
 	"mime/multipart"
 	"net/textproto"
 	"os"
+	"strconv"
 	"strings"
 	"time"
 
@@ -41,6 +42,10 @@ var CreateCmd = base.CreateCmd[*createResult]{
 		cmd := &cobra.Command{
 			Use:   "create [options] --name <name> --type <server-type> --image <image>",
 			Short: "Create a Server",
+			Long: `Create a Server.
+
+The --datacenter flag is deprecated. Use --location instead.
+See https://docs.hetzner.cloud/changelog#2025-12-16-phasing-out-datacenters.`,
 		}
 
 		cmd.Flags().String("name", "", "Server name (required)")
@@ -57,7 +62,7 @@ var CreateCmd = base.CreateCmd[*createResult]{
 		cmd.Flags().String("location", "", "Location (ID or name)")
 		_ = cmd.RegisterFlagCompletionFunc("location", cmpl.SuggestCandidatesF(client.Location().Names))
 
-		cmd.Flags().String("datacenter", "", "Datacenter (ID or name)")
+		cmd.Flags().String("datacenter", "", "Datacenter (ID or name) (deprecated)")
 		_ = cmd.RegisterFlagCompletionFunc("datacenter", cmpl.SuggestCandidatesF(client.Datacenter().Names))
 
 		cmd.Flags().StringSlice("ssh-key", nil, "ID or name of SSH Key to inject (can be specified multiple times)")
@@ -433,17 +438,40 @@ func createOptsFromFlags(
 	}
 
 	if datacenterIDOrName != "" {
-		var datacenter *hcloud.Datacenter
-		datacenter, _, err = s.Client().Datacenter().Get(s, datacenterIDOrName)
-		if err != nil {
-			return
+		cmd.PrintErrln("Warning: The --datacenter flag is deprecated. Use --location instead.")
+
+		// If parseable as ID -> GetByID and use Location Name
+		// Else -> Backwards-compatible split
+		var datacenterID int64
+		datacenterID, err = strconv.ParseInt(datacenterIDOrName, 10, 64)
+		if err == nil {
+			// Input was a valid number/ID
+			var datacenter *hcloud.Datacenter
+			datacenter, _, err = s.Client().Datacenter().GetByID(s, datacenterID)
+			if err != nil {
+				return
+			}
+			if datacenter == nil {
+				err = fmt.Errorf("Datacenter not found: %s", datacenterIDOrName)
+				return
+			}
+			createOpts.Location = datacenter.Location
+		} else {
+			// Input was not a valid number/ID, probably DC name
+
+			// Backward compatible datacenter argument.
+			// datacenter hel1-dc2 => location hel1
+			parts := strings.Split(datacenterIDOrName, "-")
+
+			if len(parts) != 2 {
+				err = fmt.Errorf("Datacenter name is not valid, expected format $LOCATION-$DATACENTER, but got: %s", datacenterIDOrName)
+				return
+			}
+
+			createOpts.Location = &hcloud.Location{Name: parts[0]}
 		}
-		if datacenter == nil {
-			err = fmt.Errorf("Datacenter not found: %s", datacenterIDOrName)
-			return
-		}
-		createOpts.Datacenter = datacenter
 	}
+
 	if locationIDOrName != "" {
 		var location *hcloud.Location
 		location, _, err = s.Client().Location().Get(s, locationIDOrName)
